@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/Parameter/BinaryEkjParameter.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -206,15 +206,18 @@ double BinaryEkjParameter::getPdf(Sample * x, int64_t kCluster) const {
 double BinaryEkjParameter::getLogLikelihoodOne() const {
 	int64_t i;
 	int64_t j;
-	double logLikelihoodOne = 0.0, pdf, * Scatter;
-	Scatter = new double[_pbDimension];
-	int64_t * Center = new int64_t[_pbDimension];
-	double * tabNbSampleInMajorModality = new double[_pbDimension];
+	double logLikelihoodOne = 0.0, pdf;//, * Scatter;
+	//Scatter = new double[_pbDimension];
+	std::unique_ptr<double[]> Scatter(new double[_pbDimension]);    
+	//int64_t * Center = new int64_t[_pbDimension];
+	std::unique_ptr<int64_t[]> Center(new int64_t[_pbDimension]);    
+	//double * tabNbSampleInMajorModality = new double[_pbDimension];
+	std::unique_ptr<double[]> tabNbSampleInMajorModality(new double[_pbDimension]);    
 	int64_t nbSample = _model->getNbSample();
 	BinaryData * data = _model->getBinaryData();
 
 	// Compute Center fo One cluster //
-	getTabCenterIfOneCluster(Center, tabNbSampleInMajorModality);
+	getTabCenterIfOneCluster(Center.get(), tabNbSampleInMajorModality.get());
 
 	// Compute Scatter for One cluster //
 	for (j = 0; j < _pbDimension; j++)
@@ -225,13 +228,13 @@ double BinaryEkjParameter::getLogLikelihoodOne() const {
 	// Compute the log-likelihood for one cluster (k=1) //
 	//--------------------------------------------------//
 	for (i = 0; i < nbSample; i++) {
-		pdf = computePdfOneCluster(data->_matrix[i], Center, Scatter, _tabNbModality);
+      pdf = computePdfOneCluster(data->_matrix[i], Center.get(), Scatter.get(), _tabNbModality);
 		logLikelihoodOne += log(pdf) * data->_weight[i];
 	}
 
-	delete[] Center;
-	delete[] Scatter;
-	delete[] tabNbSampleInMajorModality;
+	//delete[] Center;
+	//delete[] Scatter;
+	//delete[] tabNbSampleInMajorModality;
 
 	return logLikelihoodOne;
 }
@@ -350,12 +353,10 @@ void BinaryEkjParameter::editScatter(std::ofstream & oFile, int64_t k, bool text
 			;
 		}
 		for (h = 1; h <= _tabNbModality[j]; h++) {
-			if (h == _tabCenter[k][j]) {
-				oFile << _scatter[k][j] << "  ";
-			}
-			else {
-				oFile << _scatter[k][j] / (_tabNbModality[j] - 1) << "  ";
-			}
+			if (h == _tabCenter[k][j])
+				putDoubleInStream(oFile, _scatter[k][j], "  ");
+      else
+				putDoubleInStream(oFile, _scatter[k][j] / (_tabNbModality[j] - 1), "  ");
 		}
 		oFile << endl;
 	}
@@ -363,7 +364,7 @@ void BinaryEkjParameter::editScatter(std::ofstream & oFile, int64_t k, bool text
 
 // Read Scatter in input file
 //---------------------------
-void BinaryEkjParameter::inputScatter(std::ifstream & fi) {
+void BinaryEkjParameter::inputScatter(std::ifstream & fi, int64_t k) {
 	THROW(OtherException, internalMixmodError);
 }
 
